@@ -4,7 +4,7 @@ use parent qw(Alien::Base);
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 1;
 
@@ -84,7 +84,7 @@ L<http://skim.cz>
 
 =head1 CONTRIBUTORS
 
-Zakariyya Mughal L<zaki.mughal@gmail.com>
+Zakariyya Mughal L<mailto:zaki.mughal@gmail.com>
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -94,6 +94,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
